.*: Assembler messages:
.*:3: Error: Constant out of range.
.*:4: Error: Constant out of range.
.*:6: Error: Bad constant value.
.*:7: Error: Bad constant value.
.*:8: Error: Bad constant value.
.*:9: Error: Bad constant value.
.*:10: Error: Bad constant value.
.*:11: Error: Bad constant value.
.*:13: Error: Dregs expected. Input text was R3.L.
